def generate_error_dict(standard_single_names, standard_addresses, single_vowels):
    spell_dict_length = len(single_vowels["à"])
    result = {}
    full_address_result = {}
    for w in standard_single_names:
        word_lower = w.lower()
        new_words = []
        for i in range(spell_dict_length):
            new_word = ""
            for spell_key in single_vowels:
                new_word = word_lower.replace(spell_key, single_vowels[spell_key][i])
                word_lower = new_word
            new_words.append(new_word)
        result.update({w: new_words})

    for w in standard_addresses:
        word_lower = w.lower()
        new_words = []
        for i in range(spell_dict_length):
            new_word = ""
            for spell_key in single_vowels:
                new_word = word_lower.replace(spell_key, single_vowels[spell_key][i])
                word_lower = new_word
            new_words.append(new_word)
            full_address_result.update({w: new_words})

    return result, full_address_result



from .error_dict import ERROR_DICT
from .full_address_error_dict import FULL_ADDRRESS_ERROR_DICT
from .single_vowels import SINGLE_VOWELS
from .standard_addresses import STANDARD_ADDRESSES
from .standard_single_names import STANDARD_SINGLE_NAMES


import time

from fuzzywuzzy import process, fuzz


def match_word(error_dict, word_to_check, standard_single_names):
    # start = time.time()
    weight = 0
    match = ""
    for key in error_dict:
        name_to_check = word_to_check
        # standard_single_names_lower = [name.lower() for name in standard_single_names]
        if name_to_check not in standard_single_names:
            extraction = (process.extractOne(name_to_check, error_dict[key], scorer=fuzz.ratio))
            if extraction[1] > weight:
                # print(weight, key, name_to_check)
                weight = extraction[1]
                match = key
        else:
            match = name_to_check
    # end = time.time()
    # print('[{:.4f} s] Function match_word {} executed'.format((end - start), word_to_check))

    return match


def match_sentence(error_dict, sentence_to_check, standard_addresses):
    # start = time.time()
    weight = 0
    match = ""
    for key in error_dict:
        # name_to_check = sentence_to_check
        # standard_single_names_lower = [name.lower() for name in standard_single_names]
        if sentence_to_check not in standard_addresses:
            extraction = (process.extractOne(sentence_to_check, error_dict[key], scorer=fuzz.ratio))
            if extraction[1] > weight:
                # print(weight, key, name_to_check)
                weight = extraction[1]
                match = key
        else:
            match = sentence_to_check
    # end = time.time()
    # print('[{:.4f} s] Function match_sentence {} executed'.format((end - start), sentence_to_check))

    return match
